==> dnv_bladed_models-0.4.0.tar.gz: dnv_bladed_models-0.4.0/src/dnv_bladed_models/safety_system.py <==
# coding: utf-8

from __future__ import annotations

from datetime import date, datetime  # noqa: F401
from enum import Enum, IntEnum

import re  # noqa: F401
from typing import Any, Dict, List, Optional, Type, Union, Callable  # noqa: F401
from pathlib import Path
from typing import TypeVar
Model = TypeVar('Model', bound='BaseModel')
StrBytes = Union[str, bytes]

from pydantic import AnyUrl, BaseModel, EmailStr, Field, validator, root_validator, Extra,PrivateAttr  # noqa: F401
from pydantic import ValidationError
from pydantic.error_wrappers import ErrorWrapper
from pydantic.utils import ROOT_KEY
from json import encoder

from dnv_bladed_models.bladed_model import BladedModel

from dnv_bladed_models.emergency_stop_button import EmergencyStopButton

from dnv_bladed_models.generator_overpower import GeneratorOverpower

from dnv_bladed_models.generator_overspeed import GeneratorOverspeed

from dnv_bladed_models.generator_short_circuit import GeneratorShortCircuit

from dnv_bladed_models.nacelle_vibration import NacelleVibration

from dnv_bladed_models.rotor_overspeed import RotorOverspeed

from dnv_bladed_models.safety_system_circuits import SafetySystemCircuits



from .schema_helper import SchemaHelper 
from .models_impl import *
from .common_base_model import CommonBaseModel

class SafetySystem(BladedModel):
    r"""
    The definition of the turbine&#39;s safety system.  This supersedes the turbine&#39;s controller requests.
    
    Not supported yet.
    
    Attributes:
    ----------
    Circuits : SafetySystemCircuits, Not supported yet

    GeneratorOverspeed : GeneratorOverspeed, Not supported yet

    RotorOverspeed : RotorOverspeed, Not supported yet

    GeneratorOverpower : GeneratorOverpower, Not supported yet

    NacelleVibration : NacelleVibration, Not supported yet

    GeneratorShortCircuit : GeneratorShortCircuit, Not supported yet

    EmergencyStopButton : EmergencyStopButton, Not supported yet

    OnlyActivateOnceLoggingHasCommenced : bool, Not supported yet
        If true, the safety system will be inactivated during the lead in time when there is no logging.

    Notes:
    -----This model is not supported yet by the Bladed calculation engine.
    """
    _relative_schema_path: str = PrivateAttr('Turbine/BladedControl/SafetySystem/SafetySystem.json')
    
    Circuits: Optional[SafetySystemCircuits] = Field(alias="Circuits", default=SafetySystemCircuits()) # Not supported yet
    GeneratorOverspeed: Optional[GeneratorOverspeed] = Field(alias="GeneratorOverspeed", default=None) # Not supported yet
    RotorOverspeed: Optional[RotorOverspeed] = Field(alias="RotorOverspeed", default=None) # Not supported yet
    GeneratorOverpower: Optional[GeneratorOverpower] = Field(alias="GeneratorOverpower", default=None) # Not supported yet
    NacelleVibration: Optional[NacelleVibration] = Field(alias="NacelleVibration", default=None) # Not supported yet
    GeneratorShortCircuit: Optional[GeneratorShortCircuit] = Field(alias="GeneratorShortCircuit", default=None) # Not supported yet
    EmergencyStopButton: Optional[EmergencyStopButton] = Field(alias="EmergencyStopButton", default=None) # Not supported yet
    OnlyActivateOnceLoggingHasCommenced: Optional[bool] = Field(alias="OnlyActivateOnceLoggingHasCommenced", default=None) # Not supported yet

    class Config:
        extra = Extra.forbid
        validate_assignment = True
        allow_population_by_field_name = True
        pass



    def to_json(self, indent: Optional[int] = 2, **json_kwargs: Any) -> str:
        r"""
        Generates a JSON string representation of the model.

        Parameters
        ----------
        indent : int
            The whitespace indentation to use for formatting, as per json.dumps().

        Examples
        --------
        >>> model.to_json()
        Renders the full JSON representation of the model object.
        """

        json_kwargs['by_alias'] = True
        json_kwargs['exclude_unset'] = True
        json_kwargs['exclude_none'] = True
        if self.Schema is None:
            self.Schema = SchemaHelper.construct_schema_url(self._relative_schema_path)
        
        return super().json(indent=indent, **json_kwargs)


    @classmethod
    def from_file(cls: Type['Model'], path: Union[str, Path]) -> 'Model':
        r"""
        Loads a model from a given file path.

        Parameters
        ----------
        path : string
            The file path to the model.

        Returns
        -------
        SafetySystem
            The model object.

        Raises
        ------
        ValueError, ValidationError
            If the JSON document does not correctly describe the model according to the model schema.

        Examples
        --------
        >>> model = SafetySystem.from_file('/path/to/file')
        """
        
        return super().parse_file(path=path)


    @classmethod
    def from_json(cls: Type['Model'], b: StrBytes) -> 'Model':
        r"""
        Creates a model object from a JSON string.

        Parameters
        ----------
        b: StrBytes
            The JSON string describing the model.

        Returns
        -------
        SafetySystem
            The model object.

        Raises
        ------
        ValueError, ValidationError
            If the JSON document does not correctly describe the model according to the model schema.

        Examples
        --------
        >>> model = SafetySystem.from_json('{ ... }')
        """

        return super().parse_raw(
            b=b,
            content_type='application/json')
        

    @classmethod
    def from_dict(cls: Type['Model'], obj: Any) -> 'Model':
        r"""
        Creates a model object from a dict.
        
        Parameters
        ----------
        obj : Any
            The dictionary object describing the model.

        Returns
        -------
        SafetySystem
            The model object.

        Raises
        ------
        ValueError, ValidationError
            If the JSON document does not correctly describe the model according to the model schema.
        """
        
        return super().parse_obj(obj=obj)


    def to_file(self, path: Union[str, Path]):
        r"""
        Writes the model as a JSON document to a file with UTF8 encoding.

        Parameters
        ----------                
        path : string
            The file path to which the model will be written.

        Examples
        --------
        >>> model.to_file('/path/to/file')
        """

        with open(file=path, mode='w', encoding="utf8") as output_file:
            output_file.write(self.to_json())


SafetySystem.update_forward_refs()

==> dnv_bladed_models-0.4.1.tar.gz: dnv_bladed_models-0.4.1/src/dnv_bladed_models/safety_system.py <==
# coding: utf-8

from __future__ import annotations

from datetime import date, datetime  # noqa: F401
from enum import Enum, IntEnum

import re  # noqa: F401
from typing import Any, Dict, List, Optional, Type, Union, Callable  # noqa: F401
from pathlib import Path
from typing import TypeVar
Model = TypeVar('Model', bound='BaseModel')
StrBytes = Union[str, bytes]

from pydantic import AnyUrl, BaseModel, EmailStr, Field, validator, root_validator, Extra,PrivateAttr  # noqa: F401
from pydantic import ValidationError
from pydantic.error_wrappers import ErrorWrapper
from pydantic.utils import ROOT_KEY
from json import encoder

from dnv_bladed_models.bladed_model import BladedModel

from dnv_bladed_models.emergency_stop_button import EmergencyStopButton

from dnv_bladed_models.generator_overpower import GeneratorOverpower

from dnv_bladed_models.generator_overspeed import GeneratorOverspeed

from dnv_bladed_models.generator_short_circuit import GeneratorShortCircuit

from dnv_bladed_models.nacelle_vibration import NacelleVibration

from dnv_bladed_models.rotor_overspeed import RotorOverspeed

from dnv_bladed_models.safety_system_circuits import SafetySystemCircuits



from .schema_helper import SchemaHelper 
from .models_impl import *
from .common_base_model import CommonBaseModel

class SafetySystem(BladedModel):
    r"""
    The definition of the turbine&#39;s safety system.  This supersedes the turbine&#39;s controller requests.
    
    Not supported yet.
    
    Attributes:
    ----------
    Circuits : SafetySystemCircuits, Not supported yet

    GeneratorOverspeed : GeneratorOverspeed, Not supported yet

    RotorOverspeed : RotorOverspeed, Not supported yet

    GeneratorOverpower : GeneratorOverpower, Not supported yet

    NacelleVibration : NacelleVibration, Not supported yet

    GeneratorShortCircuit : GeneratorShortCircuit, Not supported yet

    EmergencyStopButton : EmergencyStopButton, Not supported yet

    OnlyActivateOnceLoggingHasCommenced : bool, Not supported yet
        If true, the safety system will be inactivated during the lead in time when there is no logging.

    Notes:
    -----This model is not supported yet by the Bladed calculation engine.
    """
    _relative_schema_path: str = PrivateAttr('Turbine/BladedControl/SafetySystem/SafetySystem.json')
    
    Circuits: Optional[SafetySystemCircuits] = Field(alias="Circuits", default=SafetySystemCircuits()) # Not supported yet
    GeneratorOverspeed: Optional[GeneratorOverspeed] = Field(alias="GeneratorOverspeed", default=None) # Not supported yet
    RotorOverspeed: Optional[RotorOverspeed] = Field(alias="RotorOverspeed", default=None) # Not supported yet
    GeneratorOverpower: Optional[GeneratorOverpower] = Field(alias="GeneratorOverpower", default=None) # Not supported yet
    NacelleVibration: Optional[NacelleVibration] = Field(alias="NacelleVibration", default=None) # Not supported yet
    GeneratorShortCircuit: Optional[GeneratorShortCircuit] = Field(alias="GeneratorShortCircuit", default=None) # Not supported yet
    EmergencyStopButton: Optional[EmergencyStopButton] = Field(alias="EmergencyStopButton", default=None) # Not supported yet
    OnlyActivateOnceLoggingHasCommenced: Optional[bool] = Field(alias="OnlyActivateOnceLoggingHasCommenced", default=None) # Not supported yet

    class Config:
        extra = Extra.forbid
        validate_assignment = True
        allow_population_by_field_name = True
        pass



    def to_json(self, indent: Optional[int] = 2, **json_kwargs: Any) -> str:
        r"""
        Generates a JSON string representation of the model.

        Parameters
        ----------
        indent : int
            The whitespace indentation to use for formatting, as per json.dumps().

        Examples
        --------
        >>> model.to_json()
        Renders the full JSON representation of the model object.
        """

        json_kwargs['by_alias'] = True
        json_kwargs['exclude_unset'] = False
        json_kwargs['exclude_none'] = True
        if self.Schema is None:
            self.Schema = SchemaHelper.construct_schema_url(self._relative_schema_path)
        
        return super().json(indent=indent, **json_kwargs)


    @classmethod
    def from_file(cls: Type['Model'], path: Union[str, Path]) -> 'Model':
        r"""
        Loads a model from a given file path.

        Parameters
        ----------
        path : string
            The file path to the model.

        Returns
        -------
        SafetySystem
            The model object.

        Raises
        ------
        ValueError, ValidationError
            If the JSON document does not correctly describe the model according to the model schema.

        Examples
        --------
        >>> model = SafetySystem.from_file('/path/to/file')
        """
        
        return super().parse_file(path=path)


    @classmethod
    def from_json(cls: Type['Model'], b: StrBytes) -> 'Model':
        r"""
        Creates a model object from a JSON string.

        Parameters
        ----------
        b: StrBytes
            The JSON string describing the model.

        Returns
        -------
        SafetySystem
            The model object.

        Raises
        ------
        ValueError, ValidationError
            If the JSON document does not correctly describe the model according to the model schema.

        Examples
        --------
        >>> model = SafetySystem.from_json('{ ... }')
        """

        return super().parse_raw(
            b=b,
            content_type='application/json')
        

    @classmethod
    def from_dict(cls: Type['Model'], obj: Any) -> 'Model':
        r"""
        Creates a model object from a dict.
        
        Parameters
        ----------
        obj : Any
            The dictionary object describing the model.

        Returns
        -------
        SafetySystem
            The model object.

        Raises
        ------
        ValueError, ValidationError
            If the JSON document does not correctly describe the model according to the model schema.
        """
        
        return super().parse_obj(obj=obj)


    def to_file(self, path: Union[str, Path]):
        r"""
        Writes the model as a JSON document to a file with UTF8 encoding.

        Parameters
        ----------                
        path : string
            The file path to which the model will be written.

        Examples
        --------
        >>> model.to_file('/path/to/file')
        """

        with open(file=path, mode='w', encoding="utf8") as output_file:
            output_file.write(self.to_json())


SafetySystem.update_forward_refs()
